@@ -13,7 +13,6 @@ from kubernetes.client.models import V1Affinity
 from kubernetes.client.models import V1Container
 from kubernetes.client.models import V1ContainerPort
 from kubernetes.client.models import V1EndpointAddress
-from kubernetes.client.models import V1EndpointPort
 from kubernetes.client.models import V1Endpoints
 from kubernetes.client.models import V1EndpointSubset
 from kubernetes.client.models import V1EnvVar
@@ -47,6 +46,11 @@ from kubernetes.client.models import V1Volume
 from kubernetes.client.models import V1VolumeMount
 from kubernetes.client.models import V1WeightedPodAffinityTerm
 
+try:
+    from kubernetes.client.models import CoreV1EndpointPort
+except ImportError:
+    from kubernetes.client.models import V1EndpointPort as CoreV1EndpointPort
+
 from kubespawner.utils import get_k8s_model
 from kubespawner.utils import update_k8s_model
 
@@ -783,7 +787,7 @@ def make_ingress(name, routespec, target, labels, data):
             subsets=[
                 V1EndpointSubset(
                     addresses=[V1EndpointAddress(ip=target_ip.compressed)],
-                    ports=[V1EndpointPort(port=target_port)],
+                    ports=[CoreV1EndpointPort(port=target_port)],
                 )
             ],
         )
